# -*- coding: utf-8 -*-
"""
Created on Fri May 12 18:55:08 2023

@author: Matthew.Cunnington
"""

import os
from pandas.tseries.offsets import CustomBusinessDay
import pandas as pd
import requests
import io


def exch_hols(n, country):

    url = 'https://raw.githubusercontent.com/mcunningto/imsholcal/main/exchange_holidays.csv'
    response = requests.get(url)
    holidays_df = pd.read_csv(io.StringIO(response.text))
	
    # Filter the DataFrame to include only holidays for the specified country
    filtered_df = holidays_df[holidays_df['country'] == country]
    # Convert the date column to datetime format with specified date format
    filtered_df['date'] = pd.to_datetime(filtered_df['date'], format='%d/%m/%Y')
    # Create a list of dates from the filtered DataFrame
    dates = filtered_df['date'].tolist()
    # Create a CustomBusinessDay object that uses the list of dates as holidays
    bday = CustomBusinessDay(holidays=dates) * n
    return bday


from setuptools import setup, find_packages

with open("README.rst", "r", encoding="utf-8") as fh:
    long_description = fh.read()

setup(
    name='imsholcal',
    use_scm_version=True,
    setup_requires=['setuptools_scm'],
    packages=find_packages(),
    install_requires=['pandas', 'requests'],
    include_package_data=True,
    url='https://github.com/mcunningto/imsholcal',
    license='MIT',
    author='mcunningto',
    author_email='mcunningto@gmail.com',
    description='business day offset function with custom exchange based holiday calendar',
    long_description=long_description,
    long_description_content_type='text/x-rst'
)
